Crate mc_sgx_io_untrusted

Crate mc_sgx_io_untrusted 

MobileCoin SGX: Untrusted (host) IO

Project ChatLicenseTargetCrates.ioDocs StatusDependency Status

Provide IO streams for the untrusted (host) side of an SGX enclave

Module for providing stderr IO from an enclave.

By default stderr from an enclave will be directed to the untrusted (host) stderr. Consumers can redirect this stream by providing a WriteAll function via stderr_sink.

Functions

stderr_sink
Specify the function to use for stderr messages

Type Aliases

WriteAll
A function that that writes the entire contents of the provided buffer.