MobileCoin SGX: Untrusted (host) IO
Provide IO streams for the untrusted (host) side of an SGX enclave
Module for providing stderr IO from an enclave.
By default stderr from an enclave will be directed to the untrusted (host)
stderr. Consumers can redirect this stream by providing a WriteAll
function via stderr_sink.
Functions
- stderr_
sink - Specify the function to use for stderr messages
Type Aliases
- Write
All - A function that that writes the entire contents of the provided buffer.